Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6138)

Unified Diff: chrome/common/extensions/extension.h

Issue 174036: Get rid of the extension's "Current Version" file. (Closed)
Patch Set: merge conflicts Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/extensions/extensions_service_unittest.cc ('k') | chrome/common/extensions/extension.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/common/extensions/extension.h
diff --git a/chrome/common/extensions/extension.h b/chrome/common/extensions/extension.h
index f3acd1ca02a8facbecc652ccabfa406232795527..34685fc882af25396cc96b6868fca704d16bd285 100644
--- a/chrome/common/extensions/extension.h
+++ b/chrome/common/extensions/extension.h
@@ -237,6 +237,10 @@ class Extension {
// an empty FilePath if the extension does not have that icon.
FilePath GetIconPath(Icons icon);
+ const DictionaryValue* manifest_value() const {
+ return manifest_value_.get();
+ }
+
// Returns a list of all locales supported by the extension.
const std::set<std::string>& supported_locales() const {
return supported_locales_;
@@ -363,7 +367,10 @@ class Extension {
// URL for fetching an update manifest
GURL update_url_;
- // List of all locales extension supports.
+ // A copy of the manifest that this extension was created from.
+ scoped_ptr<DictionaryValue> manifest_value_;
+
+ // List of all locales extension supports.
std::set<std::string> supported_locales_;
// Default locale, used for fallback.
« no previous file with comments | « chrome/browser/extensions/extensions_service_unittest.cc ('k') | chrome/common/extensions/extension.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698